# MPE/IX does not have nm, and the linker doesn't complain
# about unresolved symbols, so these are all filled in by hand.
osname='mpeix'
osvers='5.0'
alignbytes='8'
ccflags='-D_POSIX_SOURCE -D_SOCKET_SOURCE -D_POSIX_JOB_CONTROL'
cc='c89'
optimize='none'
d_safebcpy='undef'
d_safemcpy='undef'
intsize='8'
usemymalloc='y'
d_casti32='undef'
d_castneg='undef'
prefix='/PERL'
privlib='/PERL/PERL/lib'
archlib='/PERL/PERL/lib/mpeix'
clocktype='clock_t'
gidtype='gid_t'
groupstype='gid_t'
lseektype='off_t'
modetype='mode_t'
randbits='15'
ssizetype='ssize_t'
uidtype='uid_t'
d_stdstdio='undef'
i_pwd='undef'
i_grp='undef'
#d_fd_set='undef'
#d_fds_bits='undef'
d_chroot='undef'
d_fchmod='undef'
d_fchown='undef'
d_flock='undef'
d_Gconvert='sprintf((b),"%.*g",(n),(x))'
d_getpgrp2='undef'
d_getprior='undef'
d_killpg='undef'
d_lstat='undef'
d_seekdir='undef'
d_telldir='undef'
d_setpgrp2='undef'
d_setprior='undef'
d_setresgid='undef'
d_setresuid='undef'
d_setrgid='undef'
d_setruid='undef'
d_syscall='undef'
d_truncate='undef'
d_setregid='undef'
d_setreuid='undef'
d_setpgrp='undef'
d_chsize='undef'
d_group='undef'
d_bcmp='undef'
d_bcopy='undef'
d_bzero='undef'
d_attrib='undef'
d_dirnamlen='define'
d_link='undef'
d_passwd='undef'
d_pwcomment='undef'
d_statblks='undef'
libs='-lsvipc -lsocket -lm -lc'
ranlib='/bin/true'
d_nice='undef'
d_cuserid='undef'
i_termios='undef'
d_tcgetpgrp='undef'
d_tcsetpgrp='undef'
